@@ -22,7 +22,9 @@ describe('Package', () => {
 				'fixtures/first/nested/file.md',
 				'fixtures/second/file.md',
 				'fixtures/second/nested/directory/file.md',
-				'fixtures/second/nested/file.md'
+				'fixtures/second/nested/file.md',
+				'fixtures/third/library/a/book.md',
+				'fixtures/third/library/b/book.md'
 			];
 
 			const actual = fg.sync(['fixtures/**/*.md']);
@@ -67,7 +69,9 @@ describe('Package', () => {
 				'fixtures/first/nested/file.md',
 				'fixtures/second/file.md',
 				'fixtures/second/nested/directory/file.md',
-				'fixtures/second/nested/file.md'
+				'fixtures/second/nested/file.md',
+				'fixtures/third/library/a/book.md',
+				'fixtures/third/library/b/book.md'
 			];
 
 			const actual = await fg(['fixtures/**/*.md']);
@@ -112,7 +116,9 @@ describe('Package', () => {
 				'fixtures/first/nested/file.md',
 				'fixtures/second/file.md',
 				'fixtures/second/nested/directory/file.md',
-				'fixtures/second/nested/file.md'
+				'fixtures/second/nested/file.md',
+				'fixtures/third/library/a/book.md',
+				'fixtures/third/library/b/book.md'
 			];
 
 			const actual: string[] = [];
