@@ -1,11 +1,13 @@
 import * as entry from './utils/entry';
 import * as errno from './utils/errno';
 import * as pattern from './utils/pattern';
+import * as platform from './utils/platform';
 import * as task from './utils/task';
 
 export {
 	entry,
 	errno,
 	pattern,
+	platform,
 	task
 };
