@@ -504,3 +504,23 @@ smoke.suite('Smoke → Regular (relative & ignore)', [
 	{ pattern: '../{first,second}', cwd: 'fixtures/first', ignore: '../first/**' },
 	{ pattern: '../{first,second}', cwd: 'fixtures/first', ignore: '**/first/**' }
 ]);
+
+smoke.suite('Smoke -> Regular (negative group)', [
+	{
+		pattern: '**/!(*.md)',
+		cwd: 'fixtures/first'
+	}
+]);
+
+smoke.suite('Smoke -> Regular (segmented lists)', [
+	{
+		pattern: '{book.xml,**/library/*/book.md}',
+		cwd: 'fixtures/third',
+		broken: true,
+		issue: 365
+	},
+	{
+		pattern: '{book.xml,library/**/a/book.md}',
+		cwd: 'fixtures/third'
+	}
+]);
